<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WiFi вкл.</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WiFi выкл.</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock вкл.</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock выкл.</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Цифровая клавиатура вкл.</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Цифровая клавиатура выкл.</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Тачпад вкл.</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Тачпад выкл.</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Переключатель тачпада</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Переключатель Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Режим полета вкл.</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Режим полета выкл.</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Сбалансированный</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Экономия энергии</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Высокая производительность</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Оконные эффекты вкл.</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Оконные эффекты выкл.</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Не удалось включить эффекты окон</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>